@@ -30,12 +30,11 @@ async def run_job(dataset):
     # Create the job
     job = await trainml_client.jobs.create(
         name="Training Job with Local Output",
-        type="headless",
+        type="training",
         gpu_type="GTX 1060",
         gpu_count=1,
         disk_size=10,
-        worker_count=1,
-        worker_commands=[
+        workers=[
             "PYTHONPATH=$PYTHONPATH:$TRAINML_MODEL_PATH python -m official.vision.image_classification.resnet_cifar_main --num_gpus=1 --data_dir=$TRAINML_DATA_PATH --model_dir=$TRAINML_OUTPUT_PATH --enable_checkpoint_and_export=True --train_epochs=10 --batch_size=1024",
         ],
         data=dict(
