@@ -13,24 +13,24 @@ from trainml.exceptions import (
     TrainMLException,
 )
 
-pytestmark = [mark.unit, mark.jobs]
+pytestmark = [mark.sdk, mark.unit, mark.jobs]
 
 
 @fixture
 def jobs(mock_trainml):
-    return specimen.Jobs(mock_trainml)
+    yield specimen.Jobs(mock_trainml)
 
 
 @fixture
 def job(mock_trainml):
-    return specimen.Job(
+    yield specimen.Job(
         mock_trainml,
         **{
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
             "start": "2021-02-11T15:46:22.455Z",
-            "type": "interactive",
+            "type": "notebook",
             "status": "new",
             "credits_per_hour": 0.1,
             "credits": 0.1007,
@@ -246,25 +246,22 @@ class JobsTests:
     ):
         requested_config = dict(
             name="job_name",
-            type="interactive",
+            type="notebook",
             gpu_type="GTX 1060",
             gpu_count=1,
             disk_size=10,
         )
         expected_payload = dict(
             name="job_name",
-            type="interactive",
+            type="notebook",
             resources=dict(
                 gpu_type_id="1060-id",
                 gpu_count=1,
                 disk_size=10,
             ),
-            worker_count=1,
-            worker_commands=[],
             environment=dict(type="DEEPLEARNING_PY38"),
-            data=dict(datasets=[]),
             model=dict(),
-            vpn=dict(net_prefix_type_id=1),
+            worker_commands=[],
         )
 
         api_response = dict()
@@ -281,20 +278,18 @@ class JobsTests:
     ):
         requested_config = dict(
             name="job_name",
-            type="interactive",
+            type="notebook",
             gpu_type="GTX 1060",
             gpu_count=1,
             disk_size=10,
-            worker_count=None,
             worker_commands=None,
             environment=None,
             data=None,
-            vpn=None,
             source_job_uuid="job-id-1",
         )
         expected_payload = dict(
             name="job_name",
-            type="interactive",
+            type="notebook",
             resources=dict(
                 gpu_type_id="1060-id",
                 gpu_count=1,
@@ -316,7 +311,7 @@ class JobsTests:
     ):
         requested_config = dict(
             name="job_name",
-            type="interactive",
+            type="notebook",
             gpu_type="1060",
             gpu_count=1,
             disk_size=10,
@@ -368,6 +363,17 @@ class JobTests:
             "/job/job-id-1", "PATCH", None, dict(command="stop")
         )
 
+    @mark.asyncio
+    async def test_job_get_worker_log_url(self, job, mock_trainml):
+
+        api_response = "https://trainml-jobs-dev.s3.us-east-2.amazonaws.com/job-id-1/logs/worker-id-1/test_notebook.zip"
+        mock_trainml._query = AsyncMock(return_value=api_response)
+        response = await job.get_worker_log_url("worker-id-1")
+        mock_trainml._query.assert_called_once_with(
+            "/job/job-id-1/worker/worker-id-1/logs", "GET"
+        )
+        assert response == api_response
+
     @mark.asyncio
     async def test_job_get_connection_utility_url(self, job, mock_trainml):
 
@@ -396,7 +402,7 @@ class JobTests:
                 "customer_uuid": "cus-id-1",
                 "job_uuid": "job-id-1",
                 "name": "test notebook",
-                "type": "interactive",
+                "type": "notebook",
                 "status": "new",
                 "provider": "trainml",
                 "data": {
@@ -414,7 +420,6 @@ class JobTests:
                         "address": "10.106.171.253",
                         "ssh_port": 46600,
                     },
-                    "net_prefix_type_id": 1,
                 },
             },
         )
@@ -464,7 +469,7 @@ class JobTests:
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
-            "type": "interactive",
+            "type": "notebook",
             "status": "running",
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
@@ -501,7 +506,7 @@ class JobTests:
                 "customer_uuid": "cus-id-1",
                 "job_uuid": "job-id-1",
                 "name": "test notebook",
-                "type": "interactive",
+                "type": "notebook",
                 "status": "running",
                 "workers": [
                     {
@@ -578,15 +583,14 @@ class JobTests:
             name="job_copy",
         )
         expected_kwargs = {
-            "type": "interactive",
+            "type": "notebook",
             "gpu_type": "1060-id",
             "gpu_count": 1,
             "disk_size": 10,
-            "worker_count": None,
             "worker_commands": None,
+            "workers": None,
             "environment": None,
             "data": None,
-            "vpn": None,
             "source_job_uuid": "job-id-1",
         }
 
@@ -596,7 +600,7 @@ class JobTests:
                 "customer_uuid": "cus-id-1",
                 "job_uuid": "job-id-2",
                 "name": "job_copy",
-                "type": "interactive",
+                "type": "notebook",
                 "status": "new",
             },
         )
@@ -608,7 +612,7 @@ class JobTests:
         assert new_job.id == "job-id-2"
 
     @mark.asyncio
-    async def test_job_copy_headless_job_failure(
+    async def test_job_copy_training_job_failure(
         self,
         mock_trainml,
     ):
@@ -618,7 +622,7 @@ class JobTests:
                 "customer_uuid": "cus-id-1",
                 "job_uuid": "job-id-1",
                 "name": "test training",
-                "type": "headless",
+                "type": "training",
                 "status": "running",
             },
         )
@@ -633,7 +637,7 @@ class JobTests:
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
-            "type": "interactive",
+            "type": "notebook",
             "status": "running",
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
@@ -650,7 +654,7 @@ class JobTests:
                 "customer_uuid": "cus-id-1",
                 "job_uuid": "job-id-1",
                 "name": "test notebook",
-                "type": "interactive",
+                "type": "notebook",
                 "status": "running",
             },
         )
@@ -673,14 +677,14 @@ class JobTests:
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
-            "type": "interactive",
+            "type": "notebook",
             "status": "new",
         }
         api_response_final = {
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
-            "type": "interactive",
+            "type": "notebook",
             "status": "running",
         }
         mock_trainml._query = AsyncMock()
@@ -699,7 +703,7 @@ class JobTests:
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
-            "type": "interactive",
+            "type": "notebook",
             "status": "new",
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
@@ -713,7 +717,7 @@ class JobTests:
             "customer_uuid": "cus-id-1",
             "job_uuid": "job-id-1",
             "name": "test notebook",
-            "type": "interactive",
+            "type": "notebook",
             "status": "failed",
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
