@@ -86,7 +86,7 @@ class Dataset:
 
     @property
     def size(self) -> int:
-        return self._size
+        return self._size or 0
 
     def __str__(self):
         return json.dumps({k: v for k, v in self._dataset.items()})
@@ -97,6 +97,18 @@ class Dataset:
     def __bool__(self):
         return bool(self._id)
 
+    async def get_log_url(self):
+        resp = await self.trainml._query(
+            f"/dataset/pub/{self._id}/logs", "GET"
+        )
+        return resp
+
+    async def get_details(self):
+        resp = await self.trainml._query(
+            f"/dataset/pub/{self._id}/details", "GET"
+        )
+        return resp
+
     async def get_connection_utility_url(self):
         resp = await self.trainml._query(
             f"/dataset/pub/{self._id}/download", "GET"
