@@ -15,7 +15,10 @@ from trainml.connections import Connection
 
 
 def _clean_datasets_selection(
-    requested_datasets, provider, my_datasets, public_datasets
+    requested_datasets=[],
+    provider="trainml",
+    my_datasets=[],
+    public_datasets=[],
 ):
     datasets = []
     for dataset in requested_datasets:
@@ -102,12 +105,10 @@ class Jobs(object):
         gpu_type,
         gpu_count,
         disk_size,
-        worker_count=1,
         worker_commands=[],
         environment=dict(type="DEEPLEARNING_PY38"),
-        data=dict(datasets=[]),
+        data=dict(),
         model=dict(),
-        vpn=dict(net_prefix_type_id=1),
         **kwargs,
     ):
 
@@ -117,15 +118,7 @@ class Jobs(object):
                 f"'{type}' type is deprecated, use '{new_type}' instead.",
                 DeprecationWarning,
             )
-        gpu_type_task = asyncio.create_task(self.trainml.gpu_types.list())
-        my_datasets_task = asyncio.create_task(self.trainml.datasets.list())
-        public_datasets_task = asyncio.create_task(
-            self.trainml.datasets.list_public()
-        )
-
-        gpu_types, my_datasets, public_datasets = await asyncio.gather(
-            gpu_type_task, my_datasets_task, public_datasets_task
-        )
+        gpu_types = await self.trainml.gpu_types.list()
 
         selected_gpu_type = next(
             (g for g in gpu_types if g.name == gpu_type or g.id == gpu_type),
@@ -135,13 +128,23 @@ class Jobs(object):
             raise SpecificationError("gpu_type", "GPU Type Not Found")
 
         if data:
-            datasets = _clean_datasets_selection(
-                data.get("datasets"),
-                selected_gpu_type.provider,
-                my_datasets,
-                public_datasets,
-            )
-            data["datasets"] = datasets
+            if data.get("datasets"):
+                my_datasets_task = asyncio.create_task(
+                    self.trainml.datasets.list()
+                )
+                public_datasets_task = asyncio.create_task(
+                    self.trainml.datasets.list_public()
+                )
+                my_datasets, public_datasets = await asyncio.gather(
+                    my_datasets_task, public_datasets_task
+                )
+                datasets = _clean_datasets_selection(
+                    data.get("datasets"),
+                    selected_gpu_type.provider,
+                    my_datasets,
+                    public_datasets,
+                )
+                data["datasets"] = datasets
 
         config = dict(
             name=name,
@@ -151,28 +154,33 @@ class Jobs(object):
                 gpu_count=gpu_count,
                 disk_size=disk_size,
             ),
-            worker_count=worker_count,
             worker_commands=worker_commands,
+            workers=kwargs.get("workers"),
             environment=environment,
             data=data,
             model=model,
-            vpn=vpn,
             source_job_uuid=kwargs.get("source_job_uuid"),
         )
         payload = {
             k: v
             for k, v in config.items()
-            if v
-            or (
-                k in ["worker_commands", "model"]
-                and not kwargs.get("source_job_uuid")
-            )
+            if v or (k in ["model"] and not kwargs.get("source_job_uuid"))
         }
+        if (
+            not payload.get("worker_commands")
+            and not payload.get("workers")
+            and not kwargs.get("source_job_uuid")
+        ):
+            payload["worker_commands"] = []
         logging.info(f"Creating Job {name}")
+        job = await self.create_json(payload)
+        logging.info(f"Created Job {name} with id {job.id}")
+        return job
+
+    async def create_json(self, payload):
         logging.debug(f"Job payload: {payload}")
         resp = await self.trainml._query("/job", "POST", None, payload)
         job = Job(self.trainml, **resp)
-        logging.info(f"Created Job {name} with id {job.id}")
         return job
 
     async def remove(self, id):
@@ -189,6 +197,11 @@ class Job:
         self._status = self._job.get("status")
         self._type = self._job.get("type")
         self._workers = self._job.get("workers")
+        self._credits = self._job.get("credits")
+
+    @property
+    def dict(self) -> dict:
+        return {k: v for k, v in self._job.items() if k not in ["nb_token"]}
 
     @property
     def id(self) -> str:
@@ -210,15 +223,85 @@ class Job:
     def type(self) -> str:
         return self._type
 
+    @property
+    def workers(self) -> list:
+        return self._workers
+
+    @property
+    def credits(self) -> float:
+        return self._credits
+
+    @property
+    def notebook_url(self) -> str:
+        if self.type != "notebook":
+            return None
+        return f"https://notebook.trainml.ai/{self.id}/?token={self._job.get('nb_token')}"
+
     def __str__(self):
-        return json.dumps({k: v for k, v in self._job.items()})
+        return json.dumps(self.dict)
 
     def __repr__(self):
-        return f"Job( trainml , {self._job.__repr__()})"
+        return f"Job( trainml , {self.dict.__repr__()})"
 
     def __bool__(self):
         return bool(self._id)
 
+    def get_create_json(self):
+        root_keys = [
+            "name",
+            "type",
+            "resources",
+            "model",
+            "data",
+            "environment",
+            "workers",
+        ]
+        resources_keys = ["gpu_count", "gpu_type_id", "disk_size"]
+        model_keys = ["git_uri", "model_uuid"]
+        data_keys = [
+            "datasets",
+            "input_type",
+            "input_uri",
+            "output_type",
+            "output_uri",
+        ]
+        environment_keys = ["type", "env", "worker_key_types"]
+        create_json = dict()
+        for k, v in self.dict.items():
+            if k in root_keys:
+                if k == "resources":
+                    resources = dict()
+                    for k2, v2 in v.items():
+                        if k2 in resources_keys:
+                            resources[k2] = v2
+                    create_json["resources"] = resources
+                elif k == "model":
+                    model = dict()
+                    for k2, v2 in v.items():
+                        if k2 in model_keys:
+                            model[k2] = v2
+                    create_json["model"] = model
+                elif k == "data":
+                    data = dict()
+                    for k2, v2 in v.items():
+                        if k2 in data_keys:
+                            data[k2] = v2
+                    create_json["data"] = data
+                elif k == "environment":
+                    environment = dict()
+                    for k2, v2 in v.items():
+                        if k2 in environment_keys:
+                            environment[k2] = v2
+                    create_json["environment"] = environment
+                elif k == "workers":
+                    workers = []
+                    for worker in v:
+                        workers.append(worker.get("command"))
+                    create_json["workers"] = workers
+                else:
+                    create_json[k] = v
+        return create_json
+
     async def start(self):
         await self.trainml._query(
             f"/job/{self._id}", "PATCH", None, dict(command="start")
@@ -229,6 +312,12 @@ class Job:
             f"/job/{self._id}", "PATCH", None, dict(command="stop")
         )
 
+    async def get_worker_log_url(self, job_worker_uuid):
+        resp = await self.trainml._query(
+            f"/job/{self._id}/worker/{job_worker_uuid}/logs", "GET"
+        )
+        return resp
+
     async def get_connection_utility_url(self):
         resp = await self.trainml._query(f"/job/{self._id}/download", "GET")
         return resp
@@ -236,7 +325,7 @@ class Job:
     def get_connection_details(self):
 
         details = dict(
-            cidr=self._job.get("vpn").get("cidr"),
+            cidr=self.dict.get("vpn").get("cidr"),
             ssh_port=self._job.get("vpn").get("client").get("ssh_port")
             if self._job.get("vpn").get("client")
             else None,
@@ -317,11 +406,10 @@ class Job:
             or self._job.get("resources").get("gpu_count"),
             disk_size=kwargs.get("disk_size")
             or self._job.get("resources").get("disk_size"),
-            worker_count=kwargs.get("worker_count"),
             worker_commands=kwargs.get("worker_commands"),
+            workers=kwargs.get("workers"),
             environment=kwargs.get("environment"),
             data=kwargs.get("data"),
-            vpn=kwargs.get("vpn"),
             source_job_uuid=self.id,
         )
         logging.debug(f"copy result: {job}")
