@@ -2,18 +2,21 @@ import json
 import os
 import asyncio
 import aiohttp
+from importlib.metadata import version
 
-from .auth import Auth
-from .datasets import Datasets
-from .jobs import Jobs
-from .gpu_types import GpuTypes
-from .environments import Environments
-from .exceptions import ApiError, TrainMLException
-from .connections import Connections
+from trainml.auth import Auth
+from trainml.datasets import Datasets
+from trainml.models import Models
+from trainml.jobs import Jobs
+from trainml.gpu_types import GpuTypes
+from trainml.environments import Environments
+from trainml.exceptions import ApiError, TrainMLException
+from trainml.connections import Connections
 
 
 class TrainML(object):
     def __init__(self, **kwargs):
+        self._version = version("trainml")
         CONFIG_DIR = os.path.expanduser(
             os.environ.get("TRAINML_CONFIG_DIR") or "~/.trainml"
         )
@@ -31,6 +34,7 @@ class TrainML(object):
             pool_id=kwargs.get("pool_id"),
         )
         self.datasets = Datasets(self)
+        self.models = Models(self)
         self.jobs = Jobs(self)
         self.gpu_types = GpuTypes(self)
         self.environments = Environments(self)
@@ -60,6 +64,7 @@ class TrainML(object):
                 **headers,
                 **{
                     "Authorization": tokens.get("id_token"),
+                    "User-Agent": f"trainML-sdk/{self._version}",
                 },
             }
             if headers
